@@ -10,6 +10,7 @@
 ###############################################################################
 __all__ = [
     "AnalysisData",
+    "get_analysis_data",
     "fetch_ap_info",
     "load_ap_info_from_single_file",
     "SampleCollection",
@@ -18,7 +19,7 @@ __all__ = [
     "authw",
 ]
 
-from .analysis_data import AnalysisData
+from .analysis_data import AnalysisData, get_analysis_data
 from .ap_info import (
     SampleCollection,
     cache_ap_info,
