@@ -11,7 +11,7 @@
 import pytest
 
 from apd import AnalysisData
-from apd.analysis_data import sample_check
+from apd.analysis_data import APD_METADATA_CACHE_DIR, sample_check
 
 
 def test_fromcache(apinfo_cache):
@@ -22,7 +22,7 @@ def test_fromcache(apinfo_cache):
 
 
 def test_fromendpoint(monkeypatch, mocked_responses):
-    monkeypatch.setenv("APD_METADATA_CACHE_DIR", "")
+    monkeypatch.setenv(APD_METADATA_CACHE_DIR, "")
     datasets = AnalysisData("SL", "RDs")
     assert len(datasets(datatype="2012", polarity=["magup", "magdown"])) == 11
     assert len(datasets(datatype=["2012", "2016"], polarity=["magup", "magdown"])) == 25
