@@ -74,13 +74,13 @@ def apinfo_cache(tmp_path, mocked_responses):
 
 
 def test_load_from_cache(apinfo_cache):
-    pi = load_ap_info(apinfo_cache, "SL", "RDs")
+    pi, _ = load_ap_info(apinfo_cache, "SL", "RDs")
     assert len(pi.PFNs()) == 58
 
 
 def test_load_from_cache_withdate(apinfo_cache):
     ap_date = datetime.datetime(2021, 12, 1, 9, 0, 0).isoformat()
-    pi = load_ap_info(apinfo_cache, "SL", "RDs", ap_date)
+    pi, _ = load_ap_info(apinfo_cache, "SL", "RDs", ap_date)
     assert len(pi.PFNs()) == 58
 
 
